package XPanel;

use strict;
use warnings;
use vars qw{$VERSION};

BEGIN {
	require 5.8.8;
	$VERSION = '0.0.2';
}

1;
__END__

=head1 NAME

XPanel - Perl extension to XPanel servers

=head1 SYNOPSIS

  use XPanel;

=head1 DESCRIPTION

This is a placeholder for now for XPanel:: modules.

I'm doing this as a XPanel L<http://www.xpanel.com> developer for future development of our public API.

=head1 USING THE XPanel:: namespace

If you'd like to use the XPanel namespace in your modules, please use XPanel::3rdparty  or XPanel::My as your 
base namespace to avoid confusion with modules released by XPanel, Inc.

Thank you very much for your consideration in this matter.

=head1 AUTHOR

Lilian Rudenco, E<lt>http://www.xpanel.com/E<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2008 by Lilian Rudenco

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.6 or,
at your option, any later version of Perl 5 you may have available.

=cut